@@ -5,8 +5,10 @@
 #  ALL RIGHTS RESERVED.
 #
 #  Authors: Albakov Ruslan <r.albakov@abm-jsc.ru>
+from .abstract_semaphore import AbstractSemaphore
+from .key_semaphore import KeySemaphore
 from .redis_connector import RedisConnector
 from .redis_semaphore import RedisSemaphore
+from .semaphore_wrapper import SemaphoreWrapper
 
-
-__all__ = [RedisConnector, RedisSemaphore]
+__all__ = (AbstractSemaphore, KeySemaphore, RedisConnector, RedisSemaphore, SemaphoreWrapper)
